package hotswaptests;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.URL;
import java.util.Date;
import java.util.Enumeration;
import java.util.stream.Collectors;

/**
 * 
 */
public class Main {

    public static void main(String[] args) throws IOException {
        testResourceLoading("test.xml");
    }
    
    /**
     * Run this using different in options hotswap-angent.properties, 
     * to see how resource loading is affected. Also try editing resources at runtime.
     * The method never terminates. It continously prints loader resource information.
     * @throws IOException 
     */
    public static void testResourceLoading(final String resourceNameToFetch) throws IOException {
        
        for (;;) {
            Enumeration<URL> en = Thread.currentThread().getContextClassLoader().getResources("test.xml");
            System.out.println("\n============="+new Date()+" ========================");
            
            System.out.println("\n>>> Thread.currentThread().getContextClassLoader().getResources(\""+resourceNameToFetch+"\"); "+" Results in the following files:");
            for (int i=1; en.hasMoreElements();i++) {
                URL url = en.nextElement();
                System.out.println("("+i+") URL:["+url+"]");
                printStream(url.openStream());
            }

            System.out.println(">>> Main.class.getResourceAsStream(\"/"+resourceNameToFetch+"\"); "+" Results in the following file:");
            printStream(Main.class.getResourceAsStream("/"+resourceNameToFetch));
            
            System.out.println("\n==================================================");

            try {
                Thread.sleep(5000);
            } catch (InterruptedException ex) {
            }
        }
    }

    private static void printStream(InputStream is) throws IOException {
        System.out.println("\t---------- CONTENT ----------");
        try (BufferedReader br = new BufferedReader(new InputStreamReader(is))) {
            System.out.println("\t"+br.lines().collect(Collectors.joining(System.lineSeparator()+"\t")));
            System.out.println("\t-----------------------------");
        }
    }
}
